********************************************************************************************
* Author:            Kenneth Houngbedji                                                    *
* Date last updated: February 24, 2024                                                     *
* What we do here: 	 This do-file helps reproduce the main results of Botea et al. (2025)  *
********************************************************************************************

*  Preamble

clear
cap clear matrix
set matsize 1000
set emptycells drop
set more off

* Setting global macro environments


gl main "C:\WBG\github\280v2\REPLICATION PACKAGE - BOTEA ET AL 2025 - PRIVATE\Reproducibility package" // Set here directory path of the "data" folder of the reproducibility package. Eg: cd "C:\USERS\MYNAME\RP_BGHKOS_2025\Reproducibility package\data"

global raw	    "${main}\data\raw"
global build    "${main}\data\build"
global final    "${main}\data\final"
global code     "${main}\code"
global output   "${main}\outputs"

sysdir set PLUS "${main}\ado"
set varabbrev on
*  Pre-requesites commands *

qui do "${code}\00_mreg.do"    	// Multiple regressions with reg

foreach pro in estout rwolf {
	capture which `pro'
	if _rc ssc install `pro'
}

*  Session log *

cap log close REPLICATION
log using "${output}\Botea_2025.txt", name(REPLICATION) replace text

* Part 1: Producing the main databases needed to reproduce the analysis *

qui do "${code}\01_data_creation.do" 

* Part 2: Analyses that generate the result tables presented in the paper *

do "${code}\02_analysis.do" 

* End *

log close REPLICATION