use "${raw}\2011\XRMT.dta", clear
	
	isid hsclust hsstruct hsnumber mtid00id
	
	ren mtid00id terrain 
		
	replace mtid11=. if mtid11==-2
	replace mtid11=. if mtid11>=9999
	gen pclandsize = cond(mtid12 == 1, mtid11, mtid11*0.0001)
	la var pclandsize "Land size (in ha)"
	
	*when possible we replace missing parcel size with total area of plot measured with GPS
	
	preserve
		use "${raw}\2011\XGPS.dta", clear
		ren gps00 terrain
		
		replace  gps02=(gps02*0.0001) if gps03==2 & gps02>0 // conversion from sq meters to hectares
		ren gps02 ha 
		format %09.4f ha
		drop gps03
		replace ha=. if ha==-2
		replace ha=. if ha==0 // replacing plots that have impossibly small sizes (i.e., 0) as missing even though they report having harvests greater than 0
		
		collapse (sum) pcha = ha, by(hsclust hsstruct hsnumber terrain)
		
		la var  pcha "Total area of the parcel (ha) - measured with GPS"
		
		tempfile PCHAGPS
		save `"`PCHAGPS'"', replace
	restore
	
	merge 1:1 hsclust hsstruct hsnumber terrain using `"`PCHAGPS'"', keep(master matched)
	
	replace pclandsize = pcha if mi(pclandsize) & pcha != 0 & pcha!= .
	
	drop if mi(pclandsize)
	
	keep  hsclust hsstruct hsnumber terrain pclandsize
	order hsclust hsstruct hsnumber terrain pclandsize
	
	sort hsclust hsstruct hsnumber terrain
	compress
	
	tempfile TERRAINS2011
	save `"`TERRAINS2011'"', replace
	
	use "${raw}\2011\XHS.dta", clear
	
	merge 1:m hsclust hsstruct hsnumber using `"`TERRAINS2011'"', keep(master matched) nogen
	
	** IDENTIFYING LANDHOLDERS
	* Definition:
	* A landholder has reported a valid land size for a parcel that they either own or have managed during the previous 12 months
	
	gen landholder = ~mi(pclandsize)
	
	collapse (max) landholder (sum) hhnbparcels = landholder, by(hsclust hsstruct hsnumber)
	
	la var landholder "HH is landholder"
	la var hhnbparcels "Number of parcels held"
		
	keep  hsclust hsstruct hsnumber landholder hhnbparcels
	order hsclust hsstruct hsnumber landholder hhnbparcels
	
	sort hsclust hsstruct hsnumber 
	des
	
	label data "PFR 2011 IE data: Identifying households with landholdings in 2011"
	compress
save "${build}\terrains2011.dta", replace