use "${raw}\2011\XF.dta", clear
	
	gen pid = f01 
	
	preserve
		use "${raw}\2011\XRM.dta", clear
		
		gen pid = m00
		replace m07=. if m07==-2
		gen age = m07
		
		ta m12 if m12<5, gen(schl)
		gen educ=0 if m11==2
		replace educ = (m13*schl1) if schl1==1 & m13<3  // maternelle
		replace educ = (m13*schl2) if schl2==1 // primaire (ignore the 2 years of maternelle)
		replace educ = 6+(m13*schl3) if schl3==1 // primaire + secondaire 1 (college)
		replace educ = 6+4+(m13*schl4) if schl4==1 // primaire + secondaire 1 (college) + secondaire 2 (lycee)
		replace educ = 6+4+3+(m13*schl5) if schl5==1 // primaire + secondaire 1 (college) + secondaire 2 (lycee) + superieur
		replace educ=0 if mi(educ)
		bys hsclust hsstruct hsnumber: egen widowhead = max(m02 == 1 & m15 == 6)
		la var widowhead "Widow/widower head"
		
		sort hsclust hsstruct hsnumber pid
		
		keep hsclust hsstruct hsnumber pid age educ m15 m02 widowhead
		
		tempfile demovars
		save `"`demovars'"', replace
	restore
	
	merge 1:1 hsclust hsstruct hsnumber pid using `"`demovars'"', keep(master matched) nogen
	
	ren (age educ) (fage feduc)
	
	la var fage "Age of female respondent (years)"
	
	la var feduc "Years of schooling of female respondent"
	
	gen fmdkeepsomland   = inlist(f30, 1, 2, 3, 4)
	la var fmdkeepsomland "Will have land in case of death"
	
	gen fmdkeepnoland = inlist(f30, 5)
	la var fmdkeepnoland "Will have no land in case of death"
	
	gen fmddkkeepland = inlist(f30, 6)
	la var fmddkkeepland "Don't know if will keep land in case of death"
	
	gen    fmdkidkeepsomland = inlist(f31, 1, 2, 3, 4)
	la var fmdkidkeepsomland "Kids will keep land in case husband dies"
	
	gen    fmdkidkeepnoland = inlist(f31, 5)
	la var fmdkidkeepnoland "Kids will keep no land in case husband dies"
	
	gen    fmdkiddkkeepland = inlist(f31, 6)
	la var fmdkiddkkeepland "Don't know if kids will keep land in case husband dies"
	
	gen      fhadpastunion = (f32 == 1)
	replace  fhadpastunion = 1 if inlist(m15, 5, 6) & m02 == 1 // respondents who are househould head and either widow or divorcees have been previously married 
	la var   fhadpastunion "Respondent was previously in a union"
	
	gen      fhaddivorced = (f33 == 1)
	replace  fhaddivorced = 0 if inlist(m15, 6) & m02 == 1
	replace  fhaddivorced = 0 if widowhead == 1 & m02 == 1  
	la var   fhaddivorced "Respondent separated from a previous union"
	
	gen      fwaswidow = (f33 == 2)
	replace  fwaswidow = 1 if inlist(m15, 6) & m02 == 1  
	replace  fwaswidow = 1 if widowhead == 1 & m02 == 1  
	la var   fwaswidow "Respondent is widow from a previous union"
	
	gen     fwasinvillage = (f35 == 1)
	replace fwasinvillage = . if fhadpastunion == 0
	replace fwasinvillage = . if fhaddivorced == 1
	la var  fwasinvillage "Respondent was in the same village with late spouse"
	
	gen     fyearspastunion = 2011 - f34 if ~inlist(f34,., 3 , 15, 9998, 9999)
	la var  fyearspastunion "Number of years since past union ended"
	
	gen     fyearwhenwidow = cond(fwaswidow == 1, f34, .)
	replace fyearwhenwidow = . if inlist(f34,., 3 , 15, 9998, 9999)
	la var  fyearwhenwidow "Year when husband died"
	
	gen fattendoft= inlist(f51, 1, 2)
	la var fattendoft "Frequently or occasionally attends village assemblies"
	
	gen fvotelocoft= inlist(f54, 1, 2)
	la var  fvotelocoft	"Frequently or occasionally votes in local elections"
	
	gen fvotenatoft= inlist(f55, 1, 2)
	la var fvotenatoft "Frequently or occasionally votes in national elections"
	
	egen social_index = rowtotal(fattendoft fvotelocoft fvotenatoft)
	la var social_index "Political involvment index"
	
	gen fdecision = (f63 == 1)
	la var fdecision "Involved in HH's land decisions"
	
	gen frevenue = f65 
	gen frevenueoth = f65w 
	
	tab frevenueoth if frevenue!=5
	
	// Each observation that listed something else, selected "other" 
	// 3 observations selected "other" but did not fill in something else
	
	replace frevenueoth="Other family/member(s) of the HH & me" if frevenueoth=="AUTRE MEMBRES DU MENAGE ET MOI"
	replace frevenueoth="Other family/member(s) of the HH & me" if frevenueoth=="ENFANTS ET MOI"
	replace frevenueoth="Other family/member(s) of the HH & me" if frevenueoth=="LES ENFANTS ET MOI"
	replace frevenueoth="Other family/member(s) of the HH & me" if frevenueoth=="MA FILLE ET MOI"
	replace frevenueoth="Other family/member(s) of the HH & me" if frevenueoth=="MES COEPOUSES ET MOI"
	replace frevenueoth="Other family/member(s) of the HH & me" if frevenueoth=="MES ENFANTS ET MOI"
	replace frevenueoth="Other family/member(s) of the HH & me" if frevenueoth=="MOI ET LES ENFANTS"
	replace frevenueoth="Other family/member(s) of the HH & me" if frevenueoth=="MOI ET MA COEPOUSE"
	replace frevenueoth="Other family/member(s) of the HH & me" if frevenueoth=="MOI ET MES ENFANTS"
	replace frevenueoth="Other family/member(s) of the HH & me" if frevenueoth=="MON ENFANT ET MOI"
	replace frevenueoth="Other family/member(s) of the HH & me" if frevenueoth=="MON FILS ET MOI"
	
	replace frevenueoth="My spouse, me, & someone else" if frevenueoth=="MOI LUI ET SA 2E FEMME"
	replace frevenueoth="My spouse, me, & someone else" if frevenueoth=="MON MARI MES ENAFNTS ET MOI"
	replace frevenueoth="My spouse, me, & someone else" if frevenueoth=="MON MARI MOI ET MES COEPOUSES"
	
	replace frevenue=3 if frevenueoth=="My spouse, me, & someone else"
	replace frevenueoth="" if frevenueoth=="My spouse, me, & someone else"
	
	replace frevenueoth="My spouse & other members of the family/HH" if frevenueoth=="LES ENFANTS ET MARI"
	replace frevenueoth="My spouse & other members of the family/HH" if frevenueoth=="MES ENFANTS ET MON MARI"
	 
	replace frevenueoth="Worker(s)/employee(s)" if frevenueoth=="EMPLOYES"
	
	replace frevenueoth="No one" if frevenueoth=="PERSONNE"
	replace frevenueoth="No one" if frevenueoth=="PERSONNE (PAS DE CHAMP)"
	
	replace frevenue=4 if frevenueoth=="TOUS LES MENAGES"
	replace frevenueoth="" if frevenueoth=="TOUS LES MENAGES"
	
	replace frevenue=4 if frevenueoth=="TOUT LE  MENAGE"
	replace frevenueoth="" if frevenueoth=="TOUT LE  MENAGE"
	
	replace frevenue=4 if frevenueoth=="TOUT LE MENAGE"
	replace frevenueoth="" if frevenueoth=="TOUT LE MENAGE"
	
	replace frevenue=4 if frevenueoth=="MA FAMILLE"
	replace frevenueoth="" if frevenueoth=="MA FAMILLE"
	
	replace frevenue=4 if frevenueoth=="LA FAMILLE"
	replace frevenueoth="" if frevenueoth=="LA FAMILLE"
	
	replace frevenue=4 if frevenueoth=="LE MENAGE"
	replace frevenueoth="" if frevenueoth=="LE MENAGE"
	
	replace frevenueoth="Stepbrother" if frevenueoth=="BEAU-FRERE"
	replace frevenueoth="Beneficiary" if frevenueoth=="BENEFICIAIRES"
	replace frevenueoth="All of us" if frevenueoth=="CONSOMMATION DE TOUS"
	replace frevenueoth="All of us" if frevenueoth=="TOUS"
	replace frevenueoth="All of us" if frevenueoth=="ON SE PARTAGE LE REVENU"
	
	replace frevenueoth="Members of the village" if frevenueoth=="MEMBRE DU VILLAGE"
	replace frevenueoth="We do not sell the harvest" if frevenueoth=="NOUS NE VENDONS PAS LES RECOLT"
					  
	recode frevenue (5=6)
	
	replace frevenue=5 if frevenueoth=="Other family/member(s) of the HH & me" 
	replace frevenueoth="" if frevenueoth=="Other family/member(s) of the HH & me" 
	
	gen frevrec = inlist(frevenue, 1, 3, 5)
	la var frevrec "Receives at least some of the HH's agricultural revenue"
		
	gen fisolatefr = (f68 == 1)
	la var fisolatefr "Husband prevents her from seeing her friends"
	
	gen fisolatefam = (f69 == 1)
	la var fisolatefam "Husband prevents her from seeing her family"	
	
	gen ftrack = (f70 == 1)
	la var ftrack "Husband must always know her whereabouts"
	
	gen fignore = (f71 == 1)
	la var fignore "Husband ignores her & treats her indifferently"
	
	gen fotherman = (f72 == 1) 
	la var fotherman"Husband gets angry when she speaks with another man"
	
	gen fsuspect = (f73 == 1)
	la var fsuspect "Husband often suspects that she's unfaithful"
	
	egen wa_index = rowtotal(fisolatefr fisolatefam ftrack fignore fotherman fsuspect) //the lower, the better
	la var wa_index  "Women autonomy index"
	
	sort hsclust hsstruct hsnumber
	
	keep  hsclust hsstruct hsnumber fage feduc fmdkeepsomland fmdkeepnoland fmddkkeepland fmdkidkeepsomland fmdkidkeepnoland fmdkiddkkeepland /*
	*/ fhadpastunion fhaddivorced fwaswidow fwasinvillage fyearspastunion fyearwhenwidow fdecision frevrec social_index wa_index
	
	order hsclust hsstruct hsnumber fage feduc fmdkeepsomland fmdkeepnoland fmddkkeepland fmdkidkeepsomland fmdkidkeepnoland fmdkiddkkeepland /*
	*/ fhadpastunion fhaddivorced fwaswidow fwasinvillage fyearspastunion fyearwhenwidow fdecision frevrec social_index wa_index
		
save "${build}\women2011.dta", replace
