use "${raw}\2015\TRACHL.dta", clear
	
	egen __hhlvl = tag(hsclust hsstruct hsnumber)
	
	gen losthh = mi(hltrac00)
	
	tab losthh
	
	* adding data from household roster of 2015 to identify missing households that could not be surveyed
	
	gen pid2011 = hltrac00
	replace pid2011 = 1 if losthh == 1
	
	preserve
		use "${raw}\2015\RM.dta", clear
		keep hsclust hsstruct hsnumber m00 m01 m01a m02 m03 m07
		ren m00  pid2015
		ren m01a pid2011
		ren m01 name2015
		ren m02 linkhead2015
		ren m03 gender2015
		ren m07 age2015
		drop if pid2011 == 99
		drop if mi(pid2015)
		compress
		tempfile hhroster2015
		save `"`hhroster2015'"', replace
	restore
	
	merge 1:1 hsclust hsstruct hsnumber pid2011 using `"`hhroster2015'"', keep(master matched) gen(_absence)
	
	bysort hsclust hsstruct hsnumber (pid2011): egen absenthh = min(_absence == 1)
	la var absenthh "Households where no member has been surveyed in 2015"
	
	tab absenthh losthh // Absent households include lost households
	
	* Tracing other sorts of attrition 
	
	gen attrited = 0
	
	replace attrited = 1 if absenthh == 1
	
	* List of 46 HH listed in the roster of 2015 which do not match those surveyed in 2011.
	* These are sometimes cases of extended households where the unit surveyed in 2011 disappeared leaving in some cases a few members behind
	* In other cases, these discrepancies arise from relocated households that we tracked and identified as different from the target household.
	
	replace attrited = 2 if attrited == 0 & hsclust == 10 & hsstruct == 34 & hsnumber == 6
	replace attrited = 2 if attrited == 0 & hsclust == 10 & hsstruct == 48 & hsnumber == 10
	replace attrited = 2 if attrited == 0 & hsclust == 137 & hsstruct == 27 & hsnumber == 7
	replace attrited = 2 if attrited == 0 & hsclust == 177 & hsstruct == 1 & hsnumber == 2
	replace attrited = 2 if attrited == 0 & hsclust == 177 & hsstruct == 60 & hsnumber == 25
	replace attrited = 2 if attrited == 0 & hsclust == 178 & hsstruct == 36 & hsnumber == 11
	replace attrited = 2 if attrited == 0 & hsclust == 202 & hsstruct == 3 & hsnumber == 2
	replace attrited = 2 if attrited == 0 & hsclust == 203 & hsstruct == 76 & hsnumber == 10
	replace attrited = 2 if attrited == 0 & hsclust == 203 & hsstruct == 90 & hsnumber == 12
	replace attrited = 2 if attrited == 0 & hsclust == 210 & hsstruct == 17 & hsnumber == 12
	replace attrited = 2 if attrited == 0 & hsclust == 255 & hsstruct == 88 & hsnumber == 9
	replace attrited = 2 if attrited == 0 & hsclust == 255 & hsstruct == 190 & hsnumber == 17
	replace attrited = 2 if attrited == 0 & hsclust == 270 & hsstruct == 19 & hsnumber == 20
	replace attrited = 2 if attrited == 0 & hsclust == 272 & hsstruct == 3 & hsnumber == 1
	replace attrited = 2 if attrited == 0 & hsclust == 272 & hsstruct == 35 & hsnumber == 13
	replace attrited = 2 if attrited == 0 & hsclust == 285 & hsstruct == 23 & hsnumber == 14
	replace attrited = 2 if attrited == 0 & hsclust == 286 & hsstruct == 14 & hsnumber == 5
	replace attrited = 2 if attrited == 0 & hsclust == 303 & hsstruct == 32 & hsnumber == 22
	replace attrited = 2 if attrited == 0 & hsclust == 523 & hsstruct == 16 & hsnumber == 4
	replace attrited = 2 if attrited == 0 & hsclust == 524 & hsstruct == 4 & hsnumber == 3
	replace attrited = 2 if attrited == 0 & hsclust == 526 & hsstruct == 15 & hsnumber == 3
	replace attrited = 2 if attrited == 0 & hsclust == 526 & hsstruct == 61 & hsnumber == 9
	replace attrited = 2 if attrited == 0 & hsclust == 592 & hsstruct == 2 & hsnumber == 1
	replace attrited = 2 if attrited == 0 & hsclust == 626 & hsstruct == 2 & hsnumber == 1
	replace attrited = 2 if attrited == 0 & hsclust == 631 & hsstruct == 18 & hsnumber == 5
	replace attrited = 2 if attrited == 0 & hsclust == 648 & hsstruct == 39 & hsnumber == 27
	replace attrited = 2 if attrited == 0 & hsclust == 686 & hsstruct == 9 & hsnumber == 21
	replace attrited = 2 if attrited == 0 & hsclust == 747 & hsstruct == 32 & hsnumber == 13
	replace attrited = 2 if attrited == 0 & hsclust == 749 & hsstruct == 6 & hsnumber == 14
	replace attrited = 2 if attrited == 0 & hsclust == 775 & hsstruct == 31 & hsnumber == 14
	replace attrited = 2 if attrited == 0 & hsclust == 781 & hsstruct == 8 & hsnumber == 18
	replace attrited = 2 if attrited == 0 & hsclust == 782 & hsstruct == 2 & hsnumber == 3
	replace attrited = 2 if attrited == 0 & hsclust == 782 & hsstruct == 7 & hsnumber == 6
	replace attrited = 2 if attrited == 0 & hsclust == 785 & hsstruct == 108 & hsnumber == 9
	replace attrited = 2 if attrited == 0 & hsclust == 798 & hsstruct == 28 & hsnumber == 9
	replace attrited = 2 if attrited == 0 & hsclust == 801 & hsstruct == 2 & hsnumber == 2
	replace attrited = 2 if attrited == 0 & hsclust == 816 & hsstruct == 33 & hsnumber == 11
	replace attrited = 2 if attrited == 0 & hsclust == 834 & hsstruct == 92 & hsnumber == 19
	replace attrited = 2 if attrited == 0 & hsclust == 835 & hsstruct == 106 & hsnumber == 12
	replace attrited = 2 if attrited == 0 & hsclust == 836 & hsstruct == 106 & hsnumber == 15
	replace attrited = 2 if attrited == 0 & hsclust == 843 & hsstruct == 21 & hsnumber == 10
	replace attrited = 2 if attrited == 0 & hsclust == 855 & hsstruct == 38 & hsnumber == 10
	replace attrited = 2 if attrited == 0 & hsclust == 860 & hsstruct == 69 & hsnumber == 11
	replace attrited = 2 if attrited == 0 & hsclust == 863 & hsstruct == 100 & hsnumber == 20
	replace attrited = 2 if attrited == 0 & hsclust == 897 & hsstruct == 70 & hsnumber == 16
	replace attrited = 2 if attrited == 0 & hsclust == 904 & hsstruct == 12 & hsnumber == 2
	
	list hsclust hsstruct hsnumber pid2011 name2015 trac01 gender2015 trac02 linkhead2015 trac04 _absence if attrited == 2, sepby(hsclust hsstruct hsnumber)
	
	* List of 32 HHs that relocated, were tracked interviewed and looked like the original household
	
	replace attrited = 3 if attrited == 0 & hsclust == 171 & hsstruct == 48 & hsnumber == 19
	replace attrited = 3 if attrited == 0 & hsclust == 251 & hsstruct == 112 & hsnumber == 22
	replace attrited = 3 if attrited == 0 & hsclust == 281 & hsstruct == 76 & hsnumber == 14
	replace attrited = 3 if attrited == 0 & hsclust == 285 & hsstruct == 1 & hsnumber == 1
	replace attrited = 3 if attrited == 0 & hsclust == 286 & hsstruct == 13 & hsnumber == 11
	replace attrited = 3 if attrited == 0 & hsclust == 492 & hsstruct == 9 & hsnumber == 7
	replace attrited = 3 if attrited == 0 & hsclust == 538 & hsstruct == 17 & hsnumber == 11
	replace attrited = 3 if attrited == 0 & hsclust == 553 & hsstruct == 14 & hsnumber == 5
	replace attrited = 3 if attrited == 0 & hsclust == 554 & hsstruct == 9 & hsnumber == 11
	replace attrited = 3 if attrited == 0 & hsclust == 578 & hsstruct == 51 & hsnumber == 16
	replace attrited = 3 if attrited == 0 & hsclust == 631 & hsstruct == 48 & hsnumber == 13
	replace attrited = 3 if attrited == 0 & hsclust == 652 & hsstruct == 17 & hsnumber == 13
	replace attrited = 3 if attrited == 0 & hsclust == 658 & hsstruct == 5 & hsnumber == 3
	replace attrited = 3 if attrited == 0 & hsclust == 659 & hsstruct == 9 & hsnumber == 4
	replace attrited = 3 if attrited == 0 & hsclust == 714 & hsstruct == 2 & hsnumber == 3
	replace attrited = 3 if attrited == 0 & hsclust == 736 & hsstruct == 30 & hsnumber == 19
	replace attrited = 3 if attrited == 0 & hsclust == 742 & hsstruct == 5 & hsnumber == 2
	replace attrited = 3 if attrited == 0 & hsclust == 746 & hsstruct == 7 & hsnumber == 7
	replace attrited = 3 if attrited == 0 & hsclust == 759 & hsstruct == 13 & hsnumber == 16
	replace attrited = 3 if attrited == 0 & hsclust == 785 & hsstruct == 180 & hsnumber == 14
	replace attrited = 3 if attrited == 0 & hsclust == 810 & hsstruct == 125 & hsnumber == 20
	replace attrited = 3 if attrited == 0 & hsclust == 846 & hsstruct == 33 & hsnumber == 13
	replace attrited = 3 if attrited == 0 & hsclust == 852 & hsstruct == 2 & hsnumber == 2
	replace attrited = 3 if attrited == 0 & hsclust == 853 & hsstruct == 35 & hsnumber == 12
	replace attrited = 3 if attrited == 0 & hsclust == 857 & hsstruct == 13 & hsnumber == 3
	replace attrited = 3 if attrited == 0 & hsclust == 860 & hsstruct == 114 & hsnumber == 19
	replace attrited = 3 if attrited == 0 & hsclust == 883 & hsstruct == 5 & hsnumber == 2
	replace attrited = 3 if attrited == 0 & hsclust == 883 & hsstruct == 10 & hsnumber == 5
	replace attrited = 3 if attrited == 0 & hsclust == 886 & hsstruct == 7 & hsnumber == 2
	replace attrited = 3 if attrited == 0 & hsclust == 889 & hsstruct == 26 & hsnumber == 14
	replace attrited = 3 if attrited == 0 & hsclust == 897 & hsstruct == 34 & hsnumber == 8
	replace attrited = 3 if attrited == 0 & hsclust == 910 & hsstruct == 11 & hsnumber == 6
	
	list hsclust hsstruct hsnumber pid2011 name2015 trac01 gender2015 trac02 linkhead2015 trac04 _absence if attrited == 2, sepby(hsclust hsstruct hsnumber)
	
	la def attrstat  0 "Stayed" 1 "Relocated and lost" 2 "Wrong household" 3 "Relocated, found and interviewed" 
	la val attrited attrstat
	la var attrited "Attrition status - long"
	
	recode attrited (1 2 = 1) (3 = 2), gen(attrition)
	la define lattri 0 "Stayed" 1 "Relocated and lost" 2 "Relocated and interviewed"
	la values attrition lattri
	la var attrition "Attrition status"
	
	gen stayed = (attrition == 0 )
	la var  stayed "HH remained in the village"
	
	keep if __hhlvl == 1
	
	keep hsclust hsstruct hsnumber attrited attrition stayed 
		
	sort hsclust hsstruct hsnumber 
	
	label data "PFR 2015 IE data: Attrition status"
	compress
save "${build}\attrition2015.dta", replace
