use "${raw}\2015\F.dta", clear

	isid hsclust hsstruct hsnumber
	gen pid = f01 
	drop if mi(f01a)
	
	preserve
		use "${raw}\2015\RM.dta", clear
		
		drop if mi(m00)
		isid hsclust hsstruct hsnumber m00
		ren m00 pid
		
		ren m01 name
		ren m01a pid2011
		ren m02 linkhead
		
		recode m03 (2=1) (1=0), gen(fem)
		la define female 0 "male" 1 "female"
		la val fem female
		la var fem "Female"
		
		ren m07 age
		
		replace m08a=.a if m08a==8
		ren m08a origin
		
		ren m12 level
		ren m13 grade
		ren m14 diploma
		
		replace m15=.c if m15==8
		ren m15 marital
		
		la define M02en 1 "head" 2 "spouse" 3 "son/daughter" 5 "grand-son/daughter" 6 "father/mother" 7 "father/mother-in-law" ///
			8 "brother/sister" 9 "co-spouse" 10 "son/daughter-in-law" 11 "brother/sister-in-law" 12 "uncle/aunt" 13 "nephew/niece by blood" ///
			14 "nephew/niece through marriage" 15 "other relative" 16 "adopted child" 17 "no relationship" .a "I don't know"
		la val linkhead M02en
		
		la define M08Aen 1 "From this village" 2 "From another village in this commune" 3 "From another village from another commune" ///
			4 "From abroad, another African country" 5 "From outside Africa" .a "I don't know"
		la val origin M08Aen
		
		la define M15en 1 "Single" 2 "Married monogamously" 3 "Married 2 wives" 4 "Married 3 wives or more" 5 "Divorced/separated" ///
			6 "Widow/widower" 7 "Free union" .c "Non applicable"
		la val marital M15en
						
		replace grade=4 if level==2 & grade>4 & diploma==3 //4 obs; 47 remaining with CEP only, 3 no diploma
		replace grade=4 if grade>4 & level==2
		replace grade=3 if grade>3 & level==3
		
		gen educ=0 //schooling=0 or .c; level=0 or 4 (maternelle/aucun) 
		replace educ=grade if level==1 | level==6 //primary, other (1 obs)
		replace educ=6+grade if level==2 //secondary 1
		replace educ=6+4+grade if level==3 //secondary 2
		replace educ=6+4+3+grade if level==4 //superior
		la var educ "Years of schooling"
	
		bys hsclust hsstruct hsnumber : egen marrhead = max(linkhead == 1 & inlist(marital, 2, 3, 4, 7))
		bys hsclust hsstruct hsnumber : egen widowhead = max(linkhead == 1 & inlist(marital, 6))
		
		la var hsclust "Cluster number"
		la var hsstruct "Structure number"
		la var hsnumber "Household number"
		la var pid "Member ID"
		la var name "Name"
		la var pid2011 "Member ID in 2011"
		la var linkhead "Relationship to household head"
		la var origin "Origin"
		la var marital "Marital status"
		la var widowhead "Widow/widower head"
		la var widowhead "Married head"
		
		keep hsclust hsstruct hsnumber pid name pid2011 age educ origin marital linkhead marrhead widowhead 
		
		sort hsclust hsstruct hsnumber pid
		
		tempfile demovars
		save `"`demovars'"', replace
	restore
	
	merge 1:1 hsclust hsstruct hsnumber pid using `"`demovars'"', keep(master matched) nogen
	
	gen fage2015 = age
	la var fage2015 "Age (years)"
	
	gen feduc2015 = educ
	la var feduc2015 "Years of Education"
	
	gen fbornhere2015 = origin == 1
	la var fbornhere2015 "Born in this village"
	
	gen fsameas2011 = (f01a == 1)
	la var fsameas2011 "Same respondent as 2011"
	
	gen 	fmarried2015 = (f02 == 1)
	replace fmarried2015 = 1 if f02 == 2 & inlist(marital, 2, 3, 4, 7) & inlist(linkhead, 1, 2)
	la var 	fmarried2015 "Respondent was maried in 2015"
	
	gen      fhadpastunion2015 = (f32 == 1)
	replace  fhadpastunion2015 = 1 if inlist(marital, 5, 6) & linkhead == 1 // respondents who are househould head and either widow or divorcees have been previously married 
	la var   fhadpastunion2015 "Respondent was previously in a union as of 2015"
	
	gen 	 fwaswidow2015 = (f33 == 2)
	replace  fwaswidow2015 = 1 if inlist(marital, 6) & linkhead == 1  
	la var   fwaswidow2015 "Respondent is widow from a previous union as of 2015"
	
	gen 	fyearspastunion2015 = 2015 - f34 if ~inlist(f34,., 2, 999999)
	la var 	fyearspastunion2015 "Number of years since past union ended as of 2015"
	
	gen 	fyearssincewidow2015 = 2015 - f34 if ~inlist(f34,., 2, 999999) & fwaswidow2015 == 1
	la var 	fyearssincewidow2015 "Number of years since spouse died as of 2015"
	
	gen     fyearwhenwidow2015 = cond(fwaswidow2015 == 1, f34, .)
	replace fyearwhenwidow2015 = . if inlist(f34,., 2, 999999)
	la var  fyearwhenwidow2015 "Year when spouse died"
	
	sort hsclust hsstruct hsnumber
	
	keep  hsclust hsstruct hsnumber fhadpastunion2015 fwaswidow2015 fmarried2015 fyearspastunion2015 fyearwhenwidow2015 	
	order hsclust hsstruct hsnumber fhadpastunion2015 fwaswidow2015 fmarried2015 fyearspastunion2015 fyearwhenwidow2015 
	compress
save "${build}\women2015.dta", replace
