use "${raw}\2011\XCOMMUNAUTAIRE.dta", clear
	
	* Village ID variables
	
	foreach var of varlist cid1 cid3 cid5 {
		tempvar _`var'
		tostring `var', gen(`_`var'')
		replace `_`var'' = "0" + `_`var'' if `var' <= 9 
	}
	
	tempvar _cid2
	tostring cid2, gen(`_cid2')
	
	gen str codevil = `_cid1' + `_cid2' + `_cid3' + `_cid5'
	label variable codevil "Unique Identifier of the hh's village"
	
	gen hsclust = cid6
	label variable hsclust "Cluster Number"
	
	ren cid1 hsdepart 
	ren cid2 hscommun 
	ren cid3 hsarrond 
	ren cid5 hsquartier
	
	* Data cleaning
	
	*Assuming that 'other' response 'village king' can be coded back to 'village chief'
	replace s0607=3 if (s0607w=="CHOISI PAR LE ROI BALLEY DU VI"|s0607w=="CHOISI PAR LE ROI DU VILLAGE" |s0607w=="LE ROI (BALEY) DU VILLAGE"|s0607w=="PAR LE ROI ET LES SAGES")
	
	*Assuming that 'elected  by each family' can be coded back to 'elected by the villagers'
	replace s0607=1 if s0607w=="ELU PAR CHAQUE FAMILLE"| s0607w=="CHOISI PAR CHAQUE FAMILLE"
	
	replace s0608a_03=2 if s0608aw_03=="2E VICE PRESIDENT"
	replace s0608a_04=3 if s0608aw_04=="SECRETAIRE A L'INFORMATION"| s0608aw_04=="SECRETAIRE ADJOINT"| s0608aw_04=="SECRETAIRE ADJOINTE"
	replace s0608a_06=3 if s0608aw_06=="SECRETAIRE ADJOINT"
	replace s0608a_06=5 if s0608aw_06=="TRESORIER ADJOINT"
	replace s0608a_07=3 if s0608aw_07=="SECRETAIRE ADJOINT"
	replace s0608a_09=3 if s0608aw_09=="SECRETAIRE ADJOINT"
	
	*Age in section 6, question 8 (obs 8) is 5 yrs old for group member- clear mistake. Replace with missing.
	replace s0608c_08=. if s0608c_08==5  
	
	*Code back response from section 6, question 10 other into section 6, question 10.
	replace s0610_c=1 if s0610_w=="TABLEAU"
	replace s0610_x=2 if s0610_w=="TABLEAU"
	
	* Variables of interest 
	
	gen    vilwlandmgmt = (s0601 == 1)
	la var vilwlandmgmt "Village has structures that deals with land issues"
	
	gen    svgfmainlandmgmt = (inlist(s0603, 1, 2))
	la var svgfmainlandmgmt "Land issues are primarly handled by a SVGF"
	
	gen    vcouncmainlandmgmt = (s0603 == 3)
	la var vcouncmainlandmgmt "Land issues are primarly handled by the village council"
	
	gen    ecouncmainlandmgmt = (s0603 == 4)
	la var ecouncmainlandmgmt "Land issues are primarly handled by the village elders"
	
	gen    electmainlandmgmt = cond(inlist(s0607, 1,2), 1, 0)
	la var electmainlandmgmt "Members of main land management institution are elected"
	
	preserve
		keep hsdepart hscommun hsarrond hsquartier codevil s0608*
		rename *_(##)  *(#)
		reshape long s0608a s0608aw s0608b s0608c s0608d s0608dw s0608e s0608f s0608fw, i(codevil) j(member) 
		drop if mi(s0608a) & mi(s0608aw) & mi(s0608b) & mi(s0608c) & mi(s0608d) & mi(s0608dw) & mi(s0608e) & mi(s0608f) & mi(s0608fw)
		
		bys codevil: gen nmembers = _N
		la var nmembers "Number of members in the committee"
		
		bys codevil: egen nfmembers = total(s0608b==2)
		la var nfmembers "Number of female members in the committee"
		
		bys codevil: egen nleadfmembers = total(s0608b==2 & inlist(s0608a, 1, 2))
		la var nleadfmembers "Number of female members in the committee"
		
		bys codevil: keep if _n ==1
		keep hsdepart hscommun hsarrond hsquartier codevil nmembers nfmembers nleadfmembers
		
		tempfile MEMBERSLANDMGMT
		save `"`MEMBERSLANDMGMT'"'
	restore
	
	merge 1:1 hsdepart hscommun hsarrond hsquartier using `"`MEMBERSLANDMGMT'"', keepusing(nmembers nfmembers nleadfmembers) nogen
	
	foreach var of varlist nmembers nfmembers nleadfmembers {
			replace `var' = 0 if mi(`var')
	}
	
	gen    feminmainlandmgmt = (nfmembers > 0)
	la var feminmainlandmgmt "There are women in the land management committee"
	
	gen    lfeminmainlandmgmt = (nleadfmembers > 0)
	la var lfeminmainlandmgmt "There are women leading the land management committee"
	
	gen    landcommalloc = (s0611_a ==1)
	la var landcommalloc "Land committee allocates land"
	
	gen    landcommregis = (s0611_c ==1)
	la var landcommregis "Land committee registers land transactions"
	
	gen    landcommcoord = (s0611_d ==1)
	la var landcommcoord "Land committee coordonates land uses"
	
	gen    landcommarbitr = (s0611_e ==1)
	la var landcommarbitr "Land committee arbitrates land conflicts"
	
	gen    landcommenforce = (s0611_f ==1)
	la var landcommenforce "Land committee enforces the PFR"
	
	gen    landcommcollects = (s0611_g ==1)
	la var landcommcollects "Land committee collects taxes"
	
	gen    landcommprespfr = (s0611_h ==1)
	la var landcommprespfr "Land committee preserves the PFR"
	
	* Epilogue
	
	keep hsdepart hscommun hsarrond hsquartier codevil vilwlandmgmt - landcommprespfr
	
	sort codevil
	compress
		
	*Label data
	label data "WB Benin PFR 2011 IE data: community level dataset"
	
save "${build}\villages2011.dta", replace