use "${raw}\2021\quest_audio_pfr_2021.dta", clear
	
	** keeping interviews validated by headquarters
	
	keep if interview__st == 130
	
	** time of entry
	
	generate double time = clock(horodata, "YMD#hms")
	format time %tc
	la var time "Data entry time"
	
	** Type of FGD
	
	gen fgdwomen = (focus == 2)
	la var fgdwomen "Women' FGD"
	
	sort village fgdwom time
	
	** Per village and focus group we keep the latest review
	
	bys village focus (time): gen nbentries = _N
	bys village focus (time): keep if _n == _N
	
	keep  village villageid fgdwomen q2 q3 q9 q11 q12 q13 q16 q17 q18 q19 q20
	order village villageid fgdwomen q2 q3 q9 q11 q12 q13 q16 q17 q18 q19 q20
	
	** VILLAGE ID
	
	replace villageid = . if villageid == .a
	decode villageid, generate(codevil)
	bys village (codevil): replace codevil = codevil[_N] if mi(codevil)
	
	decode village, generate(namevil)
	
	drop village*
	
	order namevil codevil fgdwomen q2 q3 q9 q11 q12 q13 q16 q17 q18 q19 q20
	
	******************************************************************
	* NEW VARIABLES DESCRIBING STABLE PRACTICES AT THE VILLAGE LEVEL *
	******************************************************************
	
	rename q* q*_ 
	
	foreach var of varlist q*_ {
		local vlist "`vlist' `var'"
	}
	
	reshape wide `vlist', i(codevil) j(fgdwomen)
	
	** THERE ARE CASES OF LEVIRATE IN THE VILLAGE
	
	gen    levirate1 = q2_1 == 1
	la var levirate1 "There are cases of levirate in the village - FGD Women"
	
	gen    levirate0 = q2_0 == 1
	la var levirate0 "There are cases of levirate in the village - FGD Men"
	
	** IN CASE OF LEVIRATE, WIDOWS KEEPS HUSBANDS LAND AND HOUSIN - FGD Women"
	
	gen    leviratekeep1 = levirate1 == 1 & q3_1 == 1
	la var leviratekeep1 "In case of levirate, widows keeps husbands land and housing - FGD Women"

	gen    leviratekeep0 = levirate0 == 1 & q3_0 == 1
	la var leviratekeep0 "In case of levirate, widows keeps husbands land and housing - FGD Men"
	
	** ADVANTAGE OF HAVING A SON
	
	gen    widowsneedson1 = (q9_1 == 1)
	la var widowsneedson1 "Widows with no son are at a disadvantage for inheritance - FGD Women"

	gen    widowsneedson0 = (q9_0 == 1)
	la var widowsneedson0 "Widows with no son are at a disadvantage for inheritance - FGD Men"
	
	** POVERTY FOLLOWING WIDOWHOOD
	
	gen    widowsgetpoorer1 = (q11_1 == 1)
	la var widowsgetpoorer1 "Widows get poorer following their husband's death - FGD Women"
	
	gen    widowsgetpoorer0 = (q11_0 == 1)
	la var widowsgetpoorer0 "Widows get poorer following their husband's death - FGD Men"
	
	** WITCHCRAFT
	
	gen    widowsarewitches1 = (q12_1 == 1)
	la var widowsarewitches1 "Widows got accused of witchcraft following their husband's death - FGD Women"
	
	gen    widowsarewitches0 = (q12_0 == 1)
	la var widowsarewitches0 "Widows got accused of witchcraft following their husband's death - FGD Men"
	
	** MOST WIDOWS MOVED HOME
	
	gen    widowsmovedhome1 = (q13_1 == 1)
	la var widowsmovedhome1 "Most widows move home - FGD Women"
	
	gen    widowsmovedhome0 = (q13_0 == 1)
	la var widowsmovedhome0 "Most widows move home - FGD Men"
	
	** KNOWLEDGE OF FAMILY CODE
	
	gen    awarefamilycode1 = (q16_1 == 1)
	la var awarefamilycode1 "Focus group members are aware of the family code - FGD Women"
	
	gen    awarefamilycode0 = (q16_0 == 1)
	la var awarefamilycode0 "Focus group members are aware of the family code - FGD Men"
	
	** LAND REGISTRATION EMPOWERS WIDOWS
	
	gen    landregempowrwid1 = (q17_1 == 1)
	la var landregempowrwid1 "Land registration empowers widows - FGD Women"
	
	gen    landregempowrwid0 = (q17_0 == 1)
	la var landregempowrwid0 "Land registration empowers widows - FGD Men"

	** LAND REGISTRATION DISSUADES IN-LAWS FROM CLAIMING LAND
	
	gen    landregdisinlaws1 = (q18_1 == 1)
	la var landregdisinlaws1 "Land registration dissuades in-laws from claiming land back - FGD Women"
	
	gen    landregdisinlaws0 = (q18_0 == 1)
	la var landregdisinlaws0 "Land registration dissuades in-laws from claiming land back - FGD Men"
	
	** LAND REGISTRATION SAFEGUARD LAND RIGHTS OF MARIED WOMEN
	
	gen    landregsafmwom1 = (q19_1 == 1)
	la var landregsafmwom1 "Land registration safeguards the land rights of married women - FGD Women"
	
	gen    landregsafmwom0 = (q19_0 == 1)
	la var landregsafmwom0 "Land registration safeguards the land rights of married women - FGD Men"
	
	** WOMEN MUST BE OBEDIENT AND SUBMISSIVE TO THEIR IN-LAWS IF THEY HOPE TO ESCAPE POVERTY IN THE EVENT OF THEIR HUSBAND'S DEATH.
	
	gen    obedience1 = (q20_1 == 1)
	la var obedience1 "Women must be obedient to escape poverty - FGD Women"

	gen    obedience0 = (q20_0 == 1)
	la var obedience0 "Women must be obedient to escape poverty - FGD Men"

	** CLEANING

	drop q*

	reshape long levirate leviratekeep widowsneedson widowsgetpoorer widowsarewitches widowsmovedhome obedience awarefamilycode landregempowrwid landregdisinlaws landregsafmwom, i(codevil) j(fgd)

	la var levirate "There are cases of levirate in the village"
	la var leviratekeep "In case of levirate, widows keeps husbands land and housing"
	la var widowsneedson  "Widows with no son are at a disadvantage for inheritance"
	la var widowsgetpoorer "Widows get poorer following their husband's death"
	la var widowsarewitches "Widows got accused of witchcraft following their husband's death"
	la var widowsmovedhome "Most widows move home"
	la var awarefamilycode "Focus group members are aware of the family code"
	la var landregempowrwid "Land registration empowers widows"
	la var landregdisinlaws "Land registration dissuades in-laws from claiming land back"
	la var landregsafmwom "Land registration safeguards the land rights of married women"
	la var obedience "Women must be obedient to escape poverty"

save "${build}\villagesgd2021.dta", replace
