* 1.1: CREATING KEY DATASETS USING RAW DATA BASES *

quietly{
	do "${code}\01-01_hhhead2011.do"
	do "${code}\01-02_hhhomestead2011.do"
	do "${code}\01-03_terrains2011.do"
	do "${code}\01-04_men2011.do"
	do "${code}\01-05_women2011.do"
	do "${code}\01-06_pfrperceptions2011.do"
	
	do "${code}\01-07_attrition2015.do"	
	do "${code}\01-08_hhhead2015.do"
	do "${code}\01-09_men2015.do"	
	do "${code}\01-10_women2015.do"	
	
	do "${code}\01-11_villages2011.do"
	do "${code}\01-12_treatmentstatus.do"
	
	do "${code}\01-13_villagesgd2021.do"
}

* 1.2: DATASETS FROM THE 2021 FOCUS GROUP DISCUSSIONS *

use "${build}\villagesgd2021.dta", clear
	
	merge m:1 codevil using "${build}\treatmentstatus.dta", keep(master matched) keepusing(treated strata) nogen
	
	egen vid = group(codevil)
	la var vid "Village ID"
	
	order vid fgd strata treated
	 
	global table1 levirate leviratekeep widowsneedson widowsgetpoorer widowsarewitches widowsmovedhome obedience awarefamilycode
	global tablea7 awarefamilycode landregempowrwid landregdisinlaws landregsafmwom widowsgetpoorer
	
	keep vid fgd strata treated ${table1} ${tablea7}
	compress
	
save "${final}\widowhood2021.dta", replace

* 1.3: DATASETS FROM THE 2015 and 2011 HOUSEHOLD SURVEYS *
	
	* COMBINING HOUSEHOLD DATASETS *
	
	use "${build}\hhhead2011.dta", clear 
	
		merge 1:1 hsclust hsstruct hsnumber using "${build}\hhhomestead2011.dta", keep(master using matched) nogen
		merge 1:1 hsclust hsstruct hsnumber using "${build}\terrains2011.dta", keep(master using matched) nogen
		merge 1:1 hsclust hsstruct hsnumber using "${build}\men2011.dta", keep(master using matched) nogen
		merge 1:1 hsclust hsstruct hsnumber using "${build}\women2011.dta", keep(master using matched) nogen
		merge 1:1 hsclust hsstruct hsnumber using "${build}\pfrperceptions2011.dta", keep(master using matched) nogen
		
		merge 1:1 hsclust hsstruct hsnumber using "${build}\attrition2015.dta", keep(master using matched) nogen
		merge 1:1 hsclust hsstruct hsnumber using "${build}\hhhead2015.dta", keep(master using matched) nogen
		merge 1:1 hsclust hsstruct hsnumber using "${build}\men2015.dta", keep(master using matched) nogen
		merge 1:1 hsclust hsstruct hsnumber using "${build}\women2015.dta", keep(master using matched) nogen
		
		merge m:1 hsdepart hscommun hsarrond hsquartier using "${build}\villages2011.dta", keep(master using matched) nogen
		merge m:1 codevil using "${build}\treatmentstatus.dta", keep(master matched) nogen
	
	la var hsclust "Cluster number"
	la var hsstruct "Structure number"
	la var hsnumber "Household number"
	la var treated "Treatment - PFR village"
	
	* ADDITIONAL VARIABLES: TIMING OF SPOUSE DEATH FOR WIDOWS AND WIDOWERS *
	
	cap drop _etf_start_year
	gen _etf_start_year = year(etf_start)
	
	cap drop etf_start_year
	bys strata: egen etf_start_year = max(_etf_start_year)
	cap drop _etf_start_year
	
	cap drop widowbeforetf
	gen widowbeforetf = fyearwhenwidow <= (etf_start_year - 1) & fyearspastunion !=.
	replace widowbeforetf = . if fhadpastunion == .
	la var widowbeforetf "Widow during or after ETF"
	
	cap drop widowbeforetf2015
	gen widowbeforetf2015 = fyearwhenwidow2015 <= (etf_start_year - 1)  & fyearspastunion2015 !=.
	replace widowbeforetf2015 = . if fhadpastunion2015 == .
	la var widowbeforetf2015 "Widow during or after ETF (include 2011-2015)"
	
	cap drop widowerbeforetf
	gen widowerbeforetf = myearwhenwidow <= (etf_start_year - 1) & myearspastunion !=.
	replace widowerbeforetf = . if mhadpastunion == .
	la var widowerbeforetf "Widower during or after ETF"
	
	cap drop widowerbeforetf2015
	gen widowerbeforetf2015 = myearwhenwidow2015 <= (etf_start_year - 1) & myearspastunion2015 !=.
	replace widowerbeforetf2015 = . if mhadpastunion2015 == .
	la var widowerbeforetf2015 "Widower during or after ETF (include 2011-2015)"
	
	* ADDITIONAL VARIABLES: IDENTIFYING HOUSEHOLDS THAT STAYED AND WERE WIDOW/WIDOWER HEADED IN 2015 *
	
	gen    fwidow2015 = (stayed == 1 & widowhead2015 == 1 & femhead2015 == 1)
	la var fwidow2015 "Widow headed household in 2015"
	
	gen    mwidow2015 = (stayed == 1 & widowhead2015 == 1 & femhead2015 == 0)
	la var mwidow2015 "Widower headed housheold in 2015"
	
	egen vid = group(codevil)
	la var vid "Village ID"
	
	egen hhid = group(hsclust hsstruct hsnumber)
	la var hhid "Household ID"
	
	cap drop __village
	egen __village = tag(codevil)
	la var __village "Tags one observation for each village"
	
	
* 1.4 EPILOGUE

order hhid vid __village strata treated 

global mainvars femhead widowhead marrhead stayed youngboys fwidow2015 mwidow2015 fwaswidow2015 fmarried2015 widowbeforetf widowbeforetf2015 widowerbeforetf widowerbeforetf2015 fyearspastunion fyearspastunion2015 *widowmember* *widowermember*

global controls agehead educhead hhsize chefvillhead fonctionhead assocresphead assocmemhead

global table2 agehead educhead hhsize youngboys fage feduc fhadpastunion fhaddivorced fwaswidow widowbeforetf fwasinvillage hhhomeowner roof_ciment walls_ciment landholder hhnbparcels  
global table3 vilwlandmgmt svgfmainlandmgmt vcouncmainlandmgmt ecouncmainlandmgmt electmainlandmgmt feminmainlandmgmt lfeminmainlandmgmt landcommenforce landcommprespfr landcommregis landcommarbitr landcommcoord landcommalloc landcommcollects 
global table5 fmdkeepsomland fmdkeepnoland fmddkkeepland fmdkidkeepsomland fmdkidkeepnoland fmdkiddkkeepland 
global table6 pfraware pfrimptenurllord pfrimptenurtenant pfrimptenurwom pfrimptenurmig
global tablea1 agehead educhead hhsize youngboys fage feduc fhadpastunion fhaddivorced fwaswidow widowbeforetf fwasinvillage hhhomeowner roof_ciment walls_ciment landholder hhnbparcels
global tablea4 agehead educhead hhsize youngboys mage meduc mhadpastunion mhaddivorced mwaswidow widowerbeforetf mwasinvillage hhhomeowner roof_ciment walls_ciment landholder hhnbparcels  
global tablea6 fdecision frevrec social_index wa_index

keep hhid vid __village strata treated ${mainvars} ${controls} ${table2} ${table3} ${table5} ${table6} ${tablea1} ${tablea4} ${tablea6}

compress
cap drop __000*
notes drop _all

note: This dataset includes household-level variables extracted from the 2011 survey, supplemented with information on the household attrition status and the household head's and their partner's marital status as of 2015.
note: TS: This dataset was produced by the do-file "01_data_creation.do" on ${S_FNDATE}.
save "${final}\maindata.dta", replace