* 2.1 REPRODUCING RESULTS PRESENTED IN TABLE 1 AND TABLE A7

use "${final}\widowhood2021.dta", clear

quietly{
	
	* TABLE 1: Descriptive statistics on widow-headed and married couple households in 2011 *

	global table1 levirate leviratekeep widowsneedson widowsgetpoorer widowsarewitches widowsmovedhome obedience awarefamilycode
	
	forvalues t = 0/1 {
		eststo statsdes`t' : estpost tabstat ${table1} if fgd == `t', statistics(n mean) columns(statistics) 
	}
	
	#delimit ;
		noisily estout statsdes1 statsdes0, legend style(smcl) label 
			cells(`"count(fmt(%12.0fc) label(Obs)) mean( fmt(2) label(Mean))"')
			refcat(nomarriagehusbland "Renouncing re-marriage allows access to:", nolabel)
			prehead("" "Table 1: Practices and beliefs around widowhood and access to land for women across villages in Benin" "")  
			varlabels(
				levirate              "Cases of levirate exist in the village"
				leviratekeep          "Levirate gives access to land and housing"
				widowsneedson         "Having a son helps access to inheritance"
				widowsgetpoorer       " - most wives got poorer"
				widowsarewitches      " - some wives were accused of witchcraft"
				widowsmovedhome       " - most widows moved home"
				obedience             "Women must be obedient to escape poverty"
				awarefamilycode       "Awareness of the Family Code"
				, end("") nolast
			)    
			mgroup("Focus Group Discussion", pattern(1 0) span none) mlabel("Women" "Men")
			stats(, fmt(%12.0fc) labels("N")) eqlabels(, none) nonumber varwidth(60) ;		
	#delimit cr

	* TABLE A-7: Opinions about the effects of land registration on gender dynamics*
	
	global tablea7 awarefamilycode landregempowrwid landregdisinlaws landregsafmwom widowsgetpoorer
	count if fgd == 1
	local nvill = r(N)
	
	eststo landreg0 : estpost tabstat ${tablea7} if fgd == 0, statistics(n mean) columns(statistics) 
	eststo landreg1 : estpost tabstat ${tablea7} if fgd == 1, statistics(n mean) columns(statistics) 
	eststo landrega : estpost tabstat ${tablea7} if inlist(fgd,0, 1), statistics(n mean) columns(statistics) 
	estadd scalar N = `nvill', replace
	
	forvalues t = 0/1 {
		count if fgd == 1  & treated == `t'
		local nvill`t' = r(N)
		eststo landreg0_t`t' : estpost tabstat ${tablea7} if fgd == 0 & treated == `t', statistics(n mean) columns(statistics) 
		eststo landreg1_t`t' : estpost tabstat ${tablea7} if fgd == 1 & treated == `t', statistics(n mean) columns(statistics) 
		eststo landrega_t`t' : estpost tabstat ${tablea7} if inlist(fgd,0, 1) & treated == `t', statistics(n mean) columns(statistics) 
		estadd scalar N = `nvill`t'', replace
	}
	
	eststo landreg0_td : capture mreg ${tablea7} if fgd == 0,  iv(treated) xv(treated i.strata) diff
	eststo landreg1_td : capture mreg ${tablea7} if fgd == 1,  iv(treated) xv(treated i.strata) diff
	eststo landrega_td : capture mreg ${tablea7} if inlist(fgd,0, 1),  iv(treated) xv(treated i.strata) diff vce(cluster vid)
	estadd scalar N = `nvill', replace
	
	#delimit ;
		noisily estout landreg1_t0 landreg1_td landreg0_t0 landreg0_td , legend style(smcl) label starlevels(* 0.10 ** 0.05 *** 0.01) stardetach  
			cells(`"mean(fmt(3) pattern(1 0 1 0)) b(fmt(3) pattern(0 1 0 1) star)"' `". se(fmt(2) par pattern(0 1 0 1))"' )
			refcat(
				landregempowrwid "Land registration "
				, nolabel
			)
			prehead("" "Table A-7: Opinions about the effects of land registration on gender dynamics" "")  
			mgroup("Women" "Men" "Both", pattern(1 0 1 0)) 
			mlabel("Control" "ITT" "Control" "ITT")
			collabels("Mean" " " "Mean" " ") 
			varlabels(
				awarefamilycode       "Awareness of the Family Code"
				widowsgetpoorer       "Most widows get poorer"
				landregempowrwid      " - empowers widows"
				landregdisinlaws      " - dissuades in-laws"
				landregsafmwom        " - safeguards rights of married women"
				, end("") nolast
			)
			stats(N, fmt(%12.0fc) labels("Number of villages")) eqlabels(, none) nonumber varwidth(40) ;
	#delimit cr
}

* 2.2 REPRODUCING RESULTS PRESENTED IN TABLE 2 THROUGH 6 AND A-1 THROUGH A-6

use "${final}\maindata.dta", clear

quietly{
	
	* TABLE 2: Descriptive statistics on widow-headed and married couple households in 2011 *
	
	global table2 agehead educhead hhsize youngboys fage feduc fhadpastunion fhaddivorced fwaswidow widowbeforetf fwasinvillage hhhomeowner roof_ciment walls_ciment landholder hhnbparcels  
	
	eststo fwheadsdes11hh : estpost tabstat ${table2} if femhead == 1 & widowhead == 1, statistics(n min mean semean median sd max iqr) columns(statistics) 
	eststo fmheadsdes11hh : estpost tabstat ${table2} if marrhead== 1, statistics(n min mean semean median sd max iqr) columns(statistics) 

	#delimit ;
		noisily estout fwheadsdes11hh fmheadsdes11hh, legend style(smcl) label 
			cells(`"count(fmt(%12.0fc) label(Obs)) mean(fmt(2) label(Mean))"') 
			prehead("Table 2: Descriptive statistics on widow-headed and married couple households in 2011") 
			posthead(`""') 
			refcat(
				agehead "A. Household characteristics" 
				chrhead "Religion of the household head:" 
				fage "B. Characteristics of widows and wives"
				hhhomeowner "C. Type of homestead" 
				roof_ciment "Materials:" 
				landholder   "D. Landholdings" , 
				nolabel
			)
			varlabels(
				agehead "Age of household head (years)" 
				femhead "Female-headed household"
				educhead "Education (years)"
				hhsize "Household size"
				youngboys "Household head with a cohabiting son"
				fage  "Age (years)" 
				freadwrite  "Literacy" 
				ffrench "French literacy rate"  
				feduc "Education (years)"  
				fmarried "Currently married"  
				fyearsunion "Years since marriage"  
				fhadpastunion "Has been previously married"  
				fhaddivorced " - Divorced"  
				fwaswidow " - Widowed"  
				fwasinvillage "Widow lived in this village with late spouse "
				fyearspastunion "Years since union ended"  
				fyearssincewidow "Years since husband died"  
				widowbeforetf "Husband died before land registration started"
				fyears2remarry "Years to remarry"  
				minagegap "Age gap between husband and his oldest wife"
				hhhomeowner "Household is homeowner" 
				roof_ciment  " - roof made of cement/tiles"
				walls_ciment " - wall made of cement"
				floor_ciment " - floor made of cement"
				landholder "Household is a landholder"
				hhlandsize "Land size held by household (ha)"
				nbparcels "Number of landholdings"
				hhlandovill "Household has a parcel outside", 
				end("") nolast
			) 
			mlabel("Widowed" "Married")
			mgroup(, none) 
			eqlabels(, none) 
			stats(, fmt(%12.0fc) labels("Number of households")) 
			nonumbers 
			varwidth(55);
	#delimit cr

	* TABLE 3: Effects of land registration activities on local land management *
	
	global table3 vilwlandmgmt svgfmainlandmgmt vcouncmainlandmgmt ecouncmainlandmgmt electmainlandmgmt feminmainlandmgmt lfeminmainlandmgmt landcommenforce landcommprespfr landcommregis landcommarbitr landcommcoord landcommalloc landcommcollects 
	
	preserve
		keep if __village == 1
		eststo bittvlandmgmtrwolf: capture rwolf ${table3} , method(areg) absorb(strata) indepvar(treated) robust strata(strata) seed(1234) reps(1000)
		matrix pvrwolf = e(RW)[1..., 3]
		matrix rownames pvrwolf = ${table3}
		matrix colnames pvrwolf = prw
		estadd matrix prw = pvrwolf'
		
		count 
		local obs = r(N)
		mreg ${table3},  iv(treated) xv(treated) cons
		estadd scalar Obs = `obs'
		mat siz = e(b)
		foreach var in `: colname e(b)'	{		
			count if ~mi(`var') 
			mat siz[1, colnumb(siz,"`var'")] = r(N)
		}
		cap estadd matrix size = siz, replace
		est store cittvlandmgmt
		
		count 
		local obs = r(N)
		mreg ${table3},  iv(treated) xv(treated i.strata) diff vce(robust)
		estadd scalar Obs = `obs'
		estadd matrix prw = pvrwolf'
		est store bittvlandmgmt
		
	restore
	
	#delimit ;
		noisily estout cittvlandmgmt cittvlandmgmt bittvlandmgmt bittvlandmgmt, label starlevels(* 0.10 ** 0.05 *** 0.01) stardetach
			cells(`"obs( fmt(%12.0fc) pattern(1 0 0 0)) b(fmt(3) pattern(0 1 0 0)) b(star fmt(3) pattern(0 0 1 0)) prw(fmt(3) pattern(0 0 0 1))"'
			`". se(par abs fmt(2) pattern(0 1 0 0))  se(par abs fmt(2) pattern(0 0 1 0)) . "') 
			title(" " `"Table 3: Effects of land registration activities on local land management"' " ") 	
			refcat(
				svgfmainlandmgmt  "Land issues are primarily handled by:"
				feminmainlandmgmt "Primary land institution has at least:"
				landcommenforce   "Primary land institution: "
				, nolabel
			) 
			varlabels(
				vilwlandmgmt       "Village has institution(s) in charge of land issues"
				svgfmainlandmgmt   " - village land committee" 
				vcouncmainlandmgmt " - village council" 
				ecouncmainlandmgmt " - council of elders"
				electmainlandmgmt  "Members of primary land institution are elected"
				feminmainlandmgmt  " - one female member"
				lfeminmainlandmgmt " - one female member in a leading position"
				landcommalloc      " - allocates land to village members"
				landcommtrans      " - facilitates land transactions"
				landcommregis      " - helps register land transactions"
				landcommcoord      " - is responsible of land use management"
				landcommarbitr     " - arbitrates land conflicts"
				landcommenforce    " - coordinates land registration activities"
				landcommcollects   " - coordinates tax collection"
				landcommprespfr    " - preserves documentation about land registration"
				, end("") nolast
			) 
			mgroup("Obs." "Control" "ITT" "FWER", pattern(1 1 1 1)) collabels(" " "Mean" " " "p-value",) mlabel(, none) eqlabels(, none)
			stats( , fmt(%12.0fc)) nonumbers varwidth(50) ;		
			
	#delimit cr
	
	* TABLE 4: Land registration and likelihood that widows stay *
	
	global controls agehead educhead hhsize chefvillhead fonctionhead assocresphead assocmemhead
	
	* ALREADY WIDOWS IN 2011
	
	sum stayed if femhead == 1 & widowhead == 1 & treated == 0
	local mstay = r(mean)
	
	eststo stayfwid11 : areg stayed i.treated ${controls} if femhead == 1 & widowhead== 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mstay'
	
	eststo  stayfwid11son : areg stayed i.treated##i.youngboys ${controls} if femhead == 1 & widowhead == 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mstay'
	eststo stayfwid11sonsum : margin if youngboys == 1, dydx(treated) post grand
	
	* STAYERS WHO WERE MARRIED IN 2011 AND BECAME WIDOW IN 2015 
	
	sum fwidow2015 if marrhead == 1 & treated == 0
	local mstay = r(mean)
	
	eststo stayfwid15 : areg fwidow2015 i.treated ${controls} if marrhead== 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mstay'
	
	eststo stayfwid15son : areg fwidow2015 i.treated##i.youngboys ${controls} if marrhead== 1, absorb(strata) vce(cluster vid)
	estadd scalar Mean = `mstay'
	eststo stayfwid15sonsum : margin if youngboys == 1, dydx(treated) post grand
	
	#delimit ;
		noisily estout stayfwid11 stayfwid11son stayfwid15 stayfwid15son, label margin 
			cells(`"b(star fmt(3))"' `"se(par fmt(2))"') stardetach
			equations(1) starlevels(* 0.10 ** 0.05 *** 0.01)
			keep(1.treated 1.treated#1.youngboys 1.youngboys) 
			order(1.treated 1.treated#1.youngboys 1.youngboys)
			title(`"Table 4: Land registration and likelihood that widows stay"') 
			varlabels(
				1.youngboys "Has a cohabiting son (psi)"
				1.treated  "Lives in a PFR village (beta)" 
				1.treated#1.youngboys " x Has a cohabiting son (lambda)"
				, end("") nolast
			)
			mgroup("Panel A: Widowed in 2011" "Panel B: Married in 2011", pattern(1 0 1 0) span) 
			mlabel("(1)" "(2)" "(1)" "(2)") 
			collabels(, none) eqlabels(, none) 
			stats(N Mean, fmt(%12.0fc %12.3fc) labels(`"Number of households"' `"Likelihood to remain in the control villages"')) legend varwidth(45) nonumbers;	
			
		noisily estout stayfwid11sonsum stayfwid15sonsum, extracols(1 2) label append
			cells(`"b(star fmt(3))"' `"se(par fmt(2))"') stardetach
			equations(1) starlevels(* 0.10 ** 0.05 *** 0.01)
			keep(1.treated) 
			varlabels(
				1.treated "beta + lambda", end("") nolast
			) 
			mlabel( ,none) collabels(, none) eqlabels(, none) mgroup(, none) 
			stats(, fmt(%12.0fc 3)) varwidth(50) nonumbers;
		#delimit cr
	
	* TABLE 5: Treatment effect on married women's land bequest expectations in the event of widowhood *
	
	global table5 fmdkeepsomland fmdkeepnoland fmddkkeepland fmdkidkeepsomland fmdkidkeepnoland fmdkiddkkeepland 

	preserve
		keep if marrhead== 1 & ~mi(fmdkeepsomland)
		
		eststo bittidinherwolf: capture rwolf ${table5}, method(areg) absorb(strata) controls(${controls}) indepvar(treated) vce(cluster vid) strata(strata) seed(1234) reps(1000) 
		matrix pvrwolf = e(RW)[1..., 3]
		matrix rownames pvrwolf = ${table5}
		matrix colnames pvrwolf = prw
		estadd matrix prw = pvrwolf'
		
		count 
		local obs = r(N)
		mreg ${table5},  iv(treated) xv(treated) vce(cluster vid) cons
		estadd scalar Obs = `obs'
		mat siz = e(b)
		foreach var in `: colname e(b)'	{		
			count if ~mi(`var') 
			mat siz[1, colnumb(siz,"`var'")] = r(N)
		}
		cap estadd matrix size = siz, replace
		est store cittidinher
		
		count 
		local obs = r(N)
		mreg ${table5},  iv(treated) xv(treated ${controls} i.strata) vce(cluster vid) diff
		estadd scalar Obs = `obs'
		estadd matrix prw = pvrwolf'
		est store bittidinher
	restore
	
	#delimit ;
		noisily estout cittidinher cittidinher bittidinher bittidinher, label starlevels(* 0.10 ** 0.05 *** 0.01) stardetach
			cells(`"obs( fmt(%12.0fc) pattern(1 0 0 0)) b(fmt(3) pattern(0 1 0 0)) b(star fmt(3) pattern(0 0 1 0)) prw(fmt(3) pattern(0 0 0 1))"'
			  `". se(par abs fmt(2) pattern(0 1 0 0))  se(par abs fmt(2) pattern(0 0 1 0)) . "') 
			refcat(
				fmdkeepsomland "Wife expects she will inherit:"  
				fmdkidkeepsomland "Wife expects her children will inherit"
				, nolabel
			)
			title(" " `"Table 5: Treatment effect on married women's land bequest expectations in the event of widowhood"' " ") 			
			varlabels( 
				fmdkeepsomland    " - at least some land" 
				fmdkeepnoland     " - nothing" 
				fmddkkeepland     " - don't know"
				fmdkidkeepsomland " - at least some land" 
				fmdkidkeepnoland  " - nothing" 
				fmdkiddkkeepland  " - don't know"
				, end("") nolast
			)    
			mgroup("Obs." "Control" "ITT" "FWER", pattern(1 1 1 1)) collabels(" " "Mean" " " "p-value",) mlabel(, none) eqlabels(, none)
			stats( , fmt(%12.0fc)) nonumbers varwidth(50) ;		
		
	#delimit cr
	
	* TABLE 6: PFR'S PERCEPTIONS BY MALE HOUSEHOLD HEADS *
	
	global table6 pfraware pfrimptenurllord pfrimptenurtenant pfrimptenurwom pfrimptenurmig
	
	preserve
		keep if femhead == 0 & ~mi(pfraware)
		
		eststo bittpfrperchhrwolf: capture rwolf ${table6}, method(areg) absorb(strata) controls(${controls}) indepvar(treated) vce(cluster vid) strata(strata) seed(1234) reps(1000) 
		matrix pvrwolf = e(RW)[1..., 3]
		matrix rownames pvrwolf = ${table6}
		matrix colnames pvrwolf = prw
		estadd matrix prw = pvrwolf'
		
		count 
		local obs = r(N)
		mreg ${table6},  iv(treated) xv(treated) vce(cluster vid) cons
		estadd scalar Obs = `obs'
		mat siz = e(b)
		foreach var in `: colname e(b)'	{		
			count if ~mi(`var') 
			mat siz[1, colnumb(siz,"`var'")] = r(N)
		}
		cap estadd matrix size = siz, replace
		est store cittpfrperchh
		count 
		local obs = r(N)
		mreg ${table6},  iv(treated) xv(treated ${controls} i.strata) vce(cluster vid) diff
		estadd scalar Obs = `obs'
		estadd matrix prw = pvrwolf'
		est store bittpfrperchh
	restore
	
	#delimit ;
		noisily estout cittpfrperchh cittpfrperchh bittpfrperchh bittpfrperchh, label starlevels(* 0.10 ** 0.05 *** 0.01) stardetach
			cells(`"obs( fmt(%12.0fc) pattern(1 0 0 0)) b(fmt(3) pattern(0 1 0 0)) b(star fmt(3) pattern(0 0 1 0)) prw(fmt(3) pattern(0 0 0 1))"'
			  `". se(par abs fmt(2) pattern(0 1 0 0))  se(par abs fmt(2) pattern(0 0 1 0)) . "') 
			title(" " `"Table 6: Treatment effect on expectations of male respondents"' " ") 			
			refcat(pfrimptenurllord "Respondent thinks that PFR:", nolabel) 
			varlabels(
			pfraware "Respondent has heard about the PFR"
			pfrimptenurllord  " - improves land tenure security for landlord"
			pfrimptenurtenant " - improves land tenure security for tenants"
			pfrimptenurwom    " - improves land tenure security for women"
			pfrimptenurmig    " - improves land tenure security for migrants", 
			end("") nolast) 
			mgroup("Obs." "Control" "ITT" "FWER", pattern(1 1 1 1)) collabels(" " "Mean" " " "p-value",) mlabel(, none) eqlabels(, none)
			stats( , fmt(%12.0fc)) nonumbers varwidth(50) ;		
	#delimit cr
	
	* TABLE A-1: Descriptive statistics on widow-headed and married households in 2011 across treatment arms *
	
	global tablea1 agehead educhead hhsize youngboys fage feduc fhadpastunion fhaddivorced fwaswidow widowbeforetf fwasinvillage hhhomeowner roof_ciment walls_ciment landholder hhnbparcels
	
	forvalues t = 0/1 {
		eststo fwheadsdes11hht`t' : estpost tabstat ${tablea1} if femhead == 1 & widowhead == 1 & treated == `t', statistics(n min mean semean median sd max iqr) columns(statistics) 
		eststo fmheadsdes11hht`t' : estpost tabstat ${tablea1} if marrhead== 1 & treated == `t', statistics(n min mean semean median sd max iqr) columns(statistics) 
	}
	
	eststo fwheadsdes11hhtd : capture mreg ${tablea1} if femhead == 1 & widowhead == 1 ,  iv(treated) xv(treated i.strata) vce(cluster vid) diff
	eststo fmheadsdes11hhtd : capture mreg ${tablea1} if  marrhead== 1  ,  iv(treated) xv(treated i.strata) vce(cluster vid) diff
	
	#delimit ;
		noisily estout fwheadsdes11hht0 fwheadsdes11hhtd fmheadsdes11hht0 fmheadsdes11hhtd, style(smcl) label 
			starlevels(* 0.10 ** 0.05 *** 0.01) stardetach 
			cells(
				`"mean(fmt(3) pattern(1 0 1 0) label(Mean)) b(star fmt(3) pattern(0 1 0 1) label(coeff.))"' 
				`". se(par fmt(2)pattern(0 1 0 1) label(s.e.))"'
			)
			refcat(
				agehead "A. Characteristics of Household Heads" 
				chrhead "Religion of the household head:" 
				fage "B. Characteristics of Widows and Wives"
				finheritlanddad "Land inheritance:" 
				hhhomeowner "C. Type of homestead" 
				roof_ciment "Materials:" 
				landholder "D. Landholdings", 
				nolabel
			)
			title(`"Table A1: Descriptive statistics on widow-headed and married households in 2011 across treatment arms"') 			
			varlabels(
				agehead "Age of household head (years)" 
				femhead "Female-headed household"
				educhead "Education of household head (years)"
				hhsize "Household size"
				youngboys "Household head with a cohabiting son"
				fage  "Age (years)" 
				freadwrite  "Literacy" 
				ffrench "French literacy"  
				feduc "Education (years)"  
				fmarried "Currently married"  
				fyearsunion "Number of years since marriage"  
				fhadpastunion "Previously Married"  
				fhaddivorced " - Divorced"  
				fwaswidow " - Widowed"  
				fwasinvillage "Widow lived in this village with late spouse"
				fyearspastunion "Years since previous union ended"  
				fyearssincewidow "Years since husband died"  
				widowbeforetf "Husband died before land registration started"
				fyears2remarry "Years to remarry"  
				minagegap "Age gap between husband and his oldest wife"
				hhhomeowner "Household is homeowner" 
				roof_ciment  " - roof made of cement/tiles"
				walls_ciment " - wall made of cement"
				floor_ciment " - floor made of cement"
				landholder "Household is a landholder"
				hhlandsize "Land size held by household (ha)"
				nbparcels "Number of landholdings"
				hhlandovill "Household has a parcel outside"
				chefvillhead  "Village leader"
				conseilhead   "Village advisor"
				assocresphead "Village group leader"
				assocmemhead  "Village group member", 
				end("") nolast
			) 
			mlabel("Control" "ITT" "Control" "ITT",)    
			mgroup("Widowed" "Married", pattern(1 0 1 0)) 
			collabel("Mean" " ") 
			eqlabels(, none) 
			stats( N, fmt(%12.0fc) labels("Number of households")) 
			nonumbers legend varwidth(55);
	#delimit cr
	
	* TABLE A-2: Land registration and likelihood to stay by son presence and widowhood timing *
		
	sum stayed if femhead == 1 & widowhead == 1 & treated == 0
	local mstay = r(mean)
	
	eststo stayfwid11etfraw : areg stayed i.treated ${controls} if femhead == 1 & widowhead == 1 & fyearspastunion !=. & fwaswidow == 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mstay'
	
	eststo stayfwid11etfrawsona : areg stayed i.treated##i.youngboys ${controls} if femhead == 1 & widowhead == 1 & fyearspastunion !=. & fwaswidow == 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mstay'
	eststo stayfwid11etfrawsonasum : margin if youngboys == 1, dydx(treated) post grand
	
	eststo stayfwid11etfint : areg stayed i.treated##i.widowbeforetf ${controls} if femhead == 1 & widowhead == 1 & fyearspastunion !=. & fwaswidow == 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mstay'
	eststo stayfwid11etfintsum : margin if widowbeforetf == 1, dydx(treated) post grand
	
	eststo stayfwid11etfintsona : areg stayed i.treated##i.widowbeforetf##i.youngboys ${controls} if femhead == 1 & widowhead == 1 & fyearspastunion !=. & fwaswidow == 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mstay'
	eststo stayfwid11etfintsonasum : margin if widowbeforetf == 1 & youngboys == 1, dydx(treated) post grand
	
	#delimit ;
		noisily estout stayfwid11etfraw stayfwid11etfrawsona stayfwid11etfint stayfwid11etfintsona , label margin 
			cells(`"b(star fmt(3))"' `"se(par fmt(2))"') stardetach
			equations(1) starlevels(* 0.10 ** 0.05 *** 0.01)
			keep(1.treated 1.treated#1.youngboys 1.treated#1.widowbeforetf 1.treated#1.widowbeforetf#1.youngboys 1.youngboys 1.widowbeforetf 1.widowbeforetf#1.youngboys) 
			order(1.treated 1.treated#1.youngboys 1.treated#1.widowbeforetf 1.treated#1.widowbeforetf#1.youngboys 1.youngboys 1.widowbeforetf 1.widowbeforetf#1.youngboys)
			title(`"Table A-2: Land registration and likelihood to stay by son presence and widowhood timing"') 
			varlabels(
				1.youngboys "Widow has a cohabiting son (gamma)"
				1.widowbeforetf "Lost husband before PFR (psi)"
				1.widowbeforetf#1.youngboys " x Widow has a cohabiting son (omega)"
				1.treated  "Widow lives in a PFR village (beta)" 
				1.treated#1.youngboys " x Widow has a cohabiting son (tau)"
				1.treated#1.widowbeforetf " x Lost husband before PFR (lambda)"
				1.treated#1.widowbeforetf#1.youngboys " x Lost husband before PFR x Widow has a cohabiting son (delta)"
				, end("") nolast
			) 
			mgroup(, none) mlabel("(1)" "(2)" "(3)" "(4)") 
			collabels(,none) eqlabels(, none)  
			stats(N Mean, fmt(%12.0fc %12.3fc) labels(`"Number of households"' `"Control mean"'))
			legend varwidth(70) nonumbers;	
		
		noisily estout stayfwid11etfrawsonasum stayfwid11etfintsum stayfwid11etfintsonasum, label append extracols(1 1) margin 
			cells(`"b(star fmt(3))"' `"se(par fmt(2))"') stardetach
			equations(1) starlevels(* 0.10 ** 0.05 *** 0.01)
			keep(1.treated) 
			varlabels(
				1.treated "beta + tau + lambda + delta", end("") nolast
			) 
			mgroup(, none) 
			mlabel(, none) 
			collabels(,none) 
			eqlabels(, none)  
			stats(, fmt(%12.0fc 3)) 
			legend varwidth(61) nonumbers substitute(_ _);	
	#delimit cr
	
	* TABLE A-3: Land registration and likelihood to remarry by 2015 for widows depending on son presence and widowhood timing *
		
	sum fmarried2015 if fyearspastunion2015!=. & fwaswidow2015 == 1 & treated == 0
	local mremarry = r(mean)
	
	eststo fremarry15etfraw : areg fmarried2015 i.treated ${controls} if fyearspastunion2015!=. & fwaswidow2015 == 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mremarry'
	
	eststo fremarry15etfrawsona : areg fmarried2015 i.treated##i.youngboys ${controls} if fyearspastunion2015!=. & fwaswidow2015 == 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mremarry'
	eststo fremarry15etfrawsonasum : margin if youngboys == 1, dydx(treated) post grand
	
	eststo fremarry15etfint : areg fmarried2015 i.treated##i.widowbeforetf2015 ${controls} if fyearspastunion2015!=. & fwaswidow2015 == 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mremarry'
	eststo fremarry15etfintsum : margin if widowbeforetf2015 == 1, dydx(treated) post grand
	
	eststo fremarry15etfintsona : areg fmarried2015 i.treated##i.widowbeforetf2015##i.youngboys ${controls} if fyearspastunion2015!=. & fwaswidow2015 == 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mremarry'
	eststo fremarry15etfintsonasum : margin if widowbeforetf2015 == 1 &youngboys == 1, dydx(treated) post grand
	
	#delimit ;
		noisily estout fremarry15etfraw fremarry15etfrawsona fremarry15etfint fremarry15etfintsona, label margin 
			cells(`"b(star fmt(3))"' `"se(par fmt(2))"') stardetach
			equations(1) starlevels(* 0.10 ** 0.05 *** 0.01)
			keep(1.treated 1.treated#1.youngboys 1.treated#1.widowbeforetf2015 1.treated#1.widowbeforetf2015#1.youngboys 1.youngboys 1.widowbeforetf2015 1.widowbeforetf2015#1.youngboys) 
			order(1.treated 1.treated#1.youngboys 1.treated#1.widowbeforetf2015 1.treated#1.widowbeforetf2015#1.youngboys 1.youngboys 1.widowbeforetf2015 1.widowbeforetf2015#1.youngboys)
			title(`"Table A-3: Land registration and likelihood to remarry by 2015 for widows by son presence and widowhood timing"') 
			varlabels(
				1.youngboys "Has a cohabiting son (gamma)"
				1.widowbeforetf2015 "Lost husband before PFR (psi)"
				1.widowbeforetf2015#1.youngboys " x Widow has a cohabiting son (omega)"
				1.treated  "Widow lives in a PFR village (beta)" 
				1.treated#1.youngboys " x Widow has a cohabiting son (tau)"
				1.treated#1.widowbeforetf2015 " x Lost husband before PFR (lambda)"
				1.treated#1.widowbeforetf2015#1.youngboys " x Lost husband before PFR x Widow has a cohabiting son (delta)"
				, end("") nolast
			) 
			mgroup(, none) mlabel("(1)" "(2)" "(3)" "(4)") 
			collabels(,none) eqlabels(, none)  
			stats(N Mean, fmt(%12.0fc %12.3fc) labels(`"Number of households"' `"Control mean"'))
			varwidth(80) nonumbers;	
		
		noisily estout fremarry15etfrawsonasum fremarry15etfintsum fremarry15etfintsonasum , label append extracols(1 1) margin 
			cells(`"b(star fmt(3))"' `"se(par fmt(2))"') stardetach
			equations(1) starlevels(* 0.10 ** 0.05 *** 0.01)
			keep(1.treated) 
			varlabels(
				1.treated "beta + tau + lambda + delta", end("") nolast
			) 
			mgroup(, none) 
			mlabel(, none) 
			collabels(,none) 
			eqlabels(, none)  
			stats(, fmt(%12.0fc 3)) 
			legend varwidth(71) nonumbers substitute(_ _);	
	#delimit cr
	
	* TABLE A-4: Descriptive statistics on widowers and husbands in married couple households in 2011 *
	
	global tablea4 agehead educhead hhsize youngboys mage meduc mhadpastunion mhaddivorced mwaswidow widowerbeforetf mwasinvillage hhhomeowner roof_ciment walls_ciment landholder hhnbparcels   
	
	eststo mwheadsdes11hh : estpost tabstat ${tablea4} if femhead == 0 & widowhead == 1 , statistics(n min mean semean median sd max iqr) columns(statistics) 
	eststo mmheadsdes11hh : estpost tabstat ${tablea4} if marrhead== 1 , statistics(n min mean semean median sd max iqr) columns(statistics) 
	
	#delimit ;
		noisily estout mwheadsdes11hh mmheadsdes11hh, style(smcl) label 
			cells(`"count(fmt(%12.0fc) label(Obs)) mean(fmt(2) label(Mean))"') 
			prehead(`"Table A4: Descriptive statistics on widowers and husbands in married couple households in 2011"') 			
			posthead(`""') 
			refcat(
				agehead     "A. Characteristics of Household Heads" 
				chrhead     "Religion of the household head:" 
				mage        "B. Characteristics of Widowers and Husbands"
				hhhomeowner "C. Type of homestead" 
				roof_ciment "Materials:" 
				landholder  "D. Landholdings" , 
				nolabel
			)
			varlabels(
				agehead "Age of household head (years)" 
				memhead "Female-headed household"
				educhead "Education (years)"
				mage  "Age (years)" 
				mreadwrite  "Literacy" 
				mfrench "French literacy rate"  
				meduc "Education (years)"  
				mmarried "Currently married"  
				myearsunion "Years since marriage"  
				mhadpastunion "Has been previously married"  
				mhaddivorced " - Divorced"  
				mwaswidow " - Widowed"  
				mwasinvillage "Widower lived in this village with late spouse"
				myearspastunion "Years since union ended"  
				myearssincewidow "Years since wife died"  
				widowerbeforetf "Wife died before land registration started"
				myears2remarry "Years to remarry"  
				minagegap "Age gap between husband and his oldest wife"
				hhhomeowner "Household is homeowner" 
				roof_ciment  " - roof made of cement/tiles"
				walls_ciment " - wall made of cement"
				floor_ciment " - floor made of cement"
				landholder "Household is a landholder"
				hhlandsize "Land size held by household (ha)"
				nbparcels "Number of landholdings"
				hhlandovill "Household has a parcel outside", 
				end("") nolast
			) 
			mlabel("Widowed" "Married", span)
			mgroup(, none) 
			eqlabels(, none) 
			stats(, fmt(%12.0fc) labels("Number of households")) 
			nonumbers 
			legend 
			varwidth(50);		
	#delimit cr

	* TABLE A-5: Land registration and likelihood that widowers stay. *
	
	* ALREADY WIDOWER IN 2011
	
	sum stayed if femhead == 0 & widowhead == 1 & treated == 0
	local mstay = r(mean)
	
	eststo staymwid11 : areg stayed i.treated ${controls} if femhead == 0 & widowhead== 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mstay'
	
	eststo  staymwid11son : areg stayed i.treated##i.youngboys ${controls} if femhead == 0 & widowhead == 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mstay'
	eststo staymwid11sonsum : margin if youngboys == 1, dydx(treated) post grand
	
	* STAYERS WHO WERE MARRIED IN 2011 AND BECAME WIDOWER IN 2015 
	
	sum mwidow2015 if marrhead == 1 & treated == 0
	local mstay = r(mean)
	
	eststo staymwid15 : areg mwidow2015 i.treated ${controls} if marrhead== 1, vce(cluster vid) absorb(strata)
	estadd scalar Mean = `mstay'
	
	eststo staymwid15son : areg mwidow2015 i.treated##i.youngboys ${controls} if marrhead== 1, absorb(strata) vce(cluster vid)
	estadd scalar Mean = `mstay'
	eststo staymwid15sonsum : margin if youngboys == 1, dydx(treated) post grand
	
	#delimit ;
		noisily estout staymwid11 staymwid11son staymwid15 staymwid15son, label margin 
			cells(`"b(star fmt(4))"' `"se(par fmt(3))"') stardetach
			equations(1) starlevels(* 0.10 ** 0.05 *** 0.01)
			keep(1.treated 1.treated#1.youngboys 1.youngboys) 
			order(1.treated 1.treated#1.youngboys 1.youngboys)
			title(`"Table A-5: Land registration and likelihood that widowers stay"') 
			varlabels(
				1.youngboys "Has a cohabiting son (psi)"
				1.treated  "Lives in a PFR village (beta)" 
				1.treated#1.youngboys " x Has a cohabiting son (lambda)"
				, end("") nolast
			) 
			mgroup("Panel A: Widower in 2011" "Panel B: Married in 2011", pattern(1 0 1 0) span) 
			mlabel("(1)" "(2)" "(1)" "(2)", span) 
			collabels(, none) eqlabels(, none) 
			stats(N Mean, fmt(%12.0fc %12.3fc) labels(`"Number of households"' `"Likelihood to remain in the control villages"')) 
			varwidth(45) nonumbers;	
			
		noisily estout staymwid11sonsum staymwid15sonsum, extracols(1 2) label append margin
			cells(`"b(star fmt(4))"' `"se(par fmt(3))"') stardetach
			equations(1) starlevels(* 0.10 ** 0.05 *** 0.01)
			keep(1.treated) 
			varlabels(
				1.treated "beta + lambda", end("") nolast
			) 
			mlabel( ,none) collabels(, none) eqlabels(, none) mgroup(, none) 
			stats(, fmt(%12.0fc 3)) legend varwidth(50) nonumbers;
	#delimit cr
	
	* TABLE A-6: Treatment effect on women's empowerment *
	
	global tablea6 fdecision frevrec social_index wa_index
	
	preserve
		keep if marrhead== 1 & ~mi(fdecision)
		
		eststo bittwomemprwolf: capture rwolf ${tablea6}, method(areg) absorb(strata) controls(${controls}) indepvar(treated) vce(cluster vid) strata(strata) seed(1234) reps(1000) 
		matrix pvrwolf = e(RW)[1..., 3]
		matrix rownames pvrwolf = ${tablea6}
		matrix colnames pvrwolf = prw
		estadd matrix prw = pvrwolf'
		
		count 
		local obs = r(N)
		mreg ${tablea6},  iv(treated) xv(treated) vce(cluster vid) cons
		estadd scalar Obs = `obs'
		mat siz = e(b)
		foreach var in `: colname e(b)'	{		
			count if ~mi(`var') 
			mat siz[1, colnumb(siz,"`var'")] = r(N)
		}
		cap estadd matrix size = siz, replace
		est store cittwomemp
		count 
		local obs = r(N)
		mreg ${tablea6},  iv(treated) xv(treated ${controls} i.strata) vce(cluster vid) diff
		estadd scalar Obs = `obs'
		estadd matrix prw = pvrwolf'
		est store bittwomemp
	restore
	
	#delimit ;
		noisily estout cittwomemp cittwomemp bittwomemp bittwomemp, label starlevels(* 0.10 ** 0.05 *** 0.01) stardetach
			cells(`"obs( fmt(%12.0fc) pattern(1 0 0 0)) b(fmt(3) pattern(0 1 0 0)) b(star fmt(3) pattern(0 0 1 0)) prw(fmt(3) pattern(0 0 0 1))"'
			  `". se(par abs fmt(2) pattern(0 1 0 0))  se(par abs fmt(2) pattern(0 0 1 0)) . "') 
			title(" " `"Table A-6: Treatment effect on women's empowerment"' " ") 			
			varlabels(fdecision "Wife is involved in household's land decisions"  
			frevrec "Wife receives share of HH's ag. revenue" social_index "Political involvment index" we_index "Women's empowerment index", end("") nolast)    
			mgroup("Obs." "Control" "ITT" "FWER", pattern(1 1 1 1)) collabels(" " "Mean" " " "p-value",) mlabel(, none) eqlabels(, none)
			stats( , fmt(%12.0fc)) nonumbers varwidth(50) ;		
		
	#delimit cr
}